[llvm-commits] CVS: llvm/include/llvm/Support/ToolRunner.h

Chris Lattner lattner at cs.uiuc.edu
Tue Feb 17 00:41:02 PST 2004


Changes in directory llvm/include/llvm/Support:

ToolRunner.h updated: 1.6 -> 1.7

---
Log message:

The CBE is no longer in llvm-dis


---
Diffs of the changes:  (+2 -2)

Index: llvm/include/llvm/Support/ToolRunner.h
diff -u llvm/include/llvm/Support/ToolRunner.h:1.6 llvm/include/llvm/Support/ToolRunner.h:1.7
--- llvm/include/llvm/Support/ToolRunner.h:1.6	Tue Nov 11 16:41:31 2003
+++ llvm/include/llvm/Support/ToolRunner.h	Tue Feb 17 00:39:48 2004
@@ -95,10 +95,10 @@
 // CBE Implementation of AbstractIntepreter interface
 //
 class CBE : public AbstractInterpreter {
-  std::string DISPath;          // The path to the `llvm-dis' executable
+  std::string LLCPath;          // The path to the `llc' executable
   GCC *gcc;
 public:
-  CBE(const std::string &disPath, GCC *Gcc) : DISPath(disPath), gcc(Gcc) { }
+  CBE(const std::string &llcPath, GCC *Gcc) : LLCPath(llcPath), gcc(Gcc) { }
   ~CBE() { delete gcc; }
 
   virtual int ExecuteProgram(const std::string &Bytecode,





More information about the llvm-commits mailing list